==> react_image_annotate_ns_workflow-5.0.0.tgz: package/Components/AnnotatorForm.js <==
import { Grid } from "@mui/material";
import React from "react";
import FormOCR from "../OCR/FormOCR";
import LocalStorage from "./LocalStorage";
var Getrules = LocalStorage.get_task_rules() || {};
window.editable_fields = Getrules.editable_fields;
function AnnotatorForm(_ref) {
  var _ref$editable_arr = _ref.editable_arr,
    editable_arr = _ref$editable_arr === void 0 ? [] : _ref$editable_arr,
    setAnnotatorFormArr = _ref.setAnnotatorFormArr,
    _ref$customize_arr = _ref.customize_arr,
    customize_arr = _ref$customize_arr === void 0 ? [] : _ref$customize_arr,
    _ref$setCustomize = _ref.setCustomize,
    setCustomize = _ref$setCustomize === void 0 ? function () {} : _ref$setCustomize,
    _ref$access_block = _ref.access_block,
    access_block = _ref$access_block === void 0 ? [] : _ref$access_block,
    invalid_show = _ref.invalid_show,
    invalidForm = _ref.invalidForm,
    original_data = _ref.original_data,
    updateForm = _ref.updateForm;
  var _ref2 = Getrules || {},
    rules = _ref2.rules,
    editable_fields = _ref2.editable_fields,
    save_mandatory_fields = _ref2.save_mandatory_fields,
    find_and_replace = _ref2.find_and_replace,
    hide_physical_link = _ref2.hide_physical_link,
    dropdown_data = _ref2.dropdown_data,
    visible_fields = _ref2.visible_fields;
  return /*#__PURE__*/React.createElement(React.Fragment, null, editable_arr === null || editable_arr === void 0 ? void 0 : editable_arr.map(function (a, index) {
    var _ref3;
    return ((_ref3 = ["label", "textArea", "input", "dependentDropdown", "dropdown", "radio", "checkbox"]) === null || _ref3 === void 0 ? void 0 : _ref3.includes(a === null || a === void 0 ? void 0 : a.input_type)) && !(visible_fields === null || visible_fields === void 0 ? void 0 : visible_fields.includes(a.title)) && !(access_block === null || access_block === void 0 ? void 0 : access_block.includes(a.title)) && /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 12,
      md: 6,
      key: index,
      className: "common_inputBox"
    }, /*#__PURE__*/React.createElement(FormOCR, {
      index: index,
      editable_arr: editable_arr,
      setFormData: setAnnotatorFormArr,
      item: a,
      customized_column_arr: customize_arr,
      setCustomize: setCustomize,
      access_block: access_block,
      invalid_show: invalid_show,
      invalidForm: invalidForm,
      original_data: original_data,
      updateForm: updateForm
    }));
  }));
}
export default AnnotatorForm;

==> react_image_annotate_ns_workflow-6.0.9.tgz: package/Components/AnnotatorForm.js <==
import { Grid } from "@mui/material";
import React from "react";
import FormOCR from "../OCR/FormOCR";
import LocalStorage from "./LocalStorage";
var Getrules = LocalStorage.get_task_rules() || {};
window.editable_fields = Getrules.editable_fields;
function AnnotatorForm(_ref) {
  var _ref$editable_arr = _ref.editable_arr,
    editable_arr = _ref$editable_arr === void 0 ? [] : _ref$editable_arr,
    setAnnotatorFormArr = _ref.setAnnotatorFormArr,
    _ref$customize_arr = _ref.customize_arr,
    customize_arr = _ref$customize_arr === void 0 ? [] : _ref$customize_arr,
    _ref$setCustomize = _ref.setCustomize,
    setCustomize = _ref$setCustomize === void 0 ? function () {} : _ref$setCustomize,
    _ref$access_block = _ref.access_block,
    access_block = _ref$access_block === void 0 ? [] : _ref$access_block,
    invalid_show = _ref.invalid_show,
    invalidForm = _ref.invalidForm,
    original_data = _ref.original_data,
    updateForm = _ref.updateForm;
  var _ref2 = Getrules || {},
    rules = _ref2.rules,
    editable_fields = _ref2.editable_fields,
    save_mandatory_fields = _ref2.save_mandatory_fields,
    find_and_replace = _ref2.find_and_replace,
    hide_physical_link = _ref2.hide_physical_link,
    dropdown_data = _ref2.dropdown_data,
    visible_fields = _ref2.visible_fields;
  return /*#__PURE__*/React.createElement(React.Fragment, null, editable_arr === null || editable_arr === void 0 ? void 0 : editable_arr.map(function (a, index) {
    var _ref3;
    return ((_ref3 = ["label", "textArea", "input", "dependentDropdown", "dropdown", "radio", "checkbox", "multiSelectDropdown"]) === null || _ref3 === void 0 ? void 0 : _ref3.includes(a === null || a === void 0 ? void 0 : a.input_type)) && !(visible_fields === null || visible_fields === void 0 ? void 0 : visible_fields.includes(a.title)) && !(access_block === null || access_block === void 0 ? void 0 : access_block.includes(a.title)) && /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 12,
      md: 6,
      key: index,
      className: "common_inputBox"
    }, /*#__PURE__*/React.createElement(FormOCR, {
      index: index,
      editable_arr: editable_arr,
      setFormData: setAnnotatorFormArr,
      item: a,
      customized_column_arr: customize_arr,
      setCustomize: setCustomize,
      access_block: access_block,
      invalid_show: invalid_show,
      invalidForm: invalidForm,
      original_data: original_data,
      updateForm: updateForm
    }));
  }));
}
export default AnnotatorForm;
